@@ -232,14 +232,19 @@ namespace Tomboy.Sync
 
 		static void HandleNoteBufferChanged (Note note)
 		{
-			// If note text changes, kill the timer.  It will
-			// automatically be resurrected once a Save occurs.
+			// Note changed, iff a sync is coming up we kill the
+			// timer to avoid interupting the user (we want to
+			// make sure not to sync more often than the user's pref)
 			if (syncThread == null && autosyncTimer != null) {
-				Logger.Debug ("Note edited...killing autosync timer until next save or delete event");
-				autosyncTimer.Dispose ();
-				autosyncTimer = null;
+				TimeSpan timeSinceLastCheck =
+					DateTime.Now - lastBackgroundCheck;
+				if (timeSinceLastCheck.TotalMinutes > autosyncTimeoutPrefMinutes - 1) {
+					Logger.Debug ("Note edited...killing autosync timer until next save or delete event");
+					autosyncTimer.Dispose ();
+					autosyncTimer = null;
+					NoteMgr.NoteBufferChanged -= HandleNoteBufferChanged;
+				}
 			}
-			NoteMgr.NoteBufferChanged -= HandleNoteBufferChanged;
 		}
 
 		static void Preferences_SettingChanged (object sender, EventArgs args)
@@ -271,8 +276,8 @@ namespace Tomboy.Sync
 					Logger.Debug ("Autosync pref changed...restarting sync timer");
 					autosyncTimeoutPrefMinutes = autosyncTimeoutPrefMinutes >= 5 ? autosyncTimeoutPrefMinutes : 5;
 					lastBackgroundCheck = DateTime.Now;
-					 // Perform a sync one minute after setting change
-					currentAutosyncTimeoutMinutes = 1;
+					 // Perform a sync no sooner than user specified
+					currentAutosyncTimeoutMinutes = autosyncTimeoutPrefMinutes;
 					autosyncTimer = new Timer ((o) => BackgroundSyncChecker (),
 					                           null,
 					                           currentAutosyncTimeoutMinutes * 60000,
@@ -392,7 +397,7 @@ namespace Tomboy.Sync
 						throw new Exception ("addin.CreateSyncServer () returned null");
 				} catch (Exception e) {
 					SetState (SyncState.SyncServerCreationFailed);
-					Logger.Log ("Exception while creating SyncServer: {0}\n{1}", e.Message, e.StackTrace);
+					Logger.Error ("Exception while creating SyncServer: {0}\n{1}", e.Message, e.StackTrace);
 					SetState (SyncState.Idle);
 					syncThread = null;
 					addin.PostSyncCleanup ();// TODO: Needed?
@@ -407,7 +412,7 @@ namespace Tomboy.Sync
 				// TODO: We should really throw exceptions from BeginSyncTransaction ()
 				if (!server.BeginSyncTransaction ()) {
 					SetState (SyncState.Locked);
-					Logger.Log ("PerformSynchronization: Server locked, try again later");
+					Logger.Warn ("PerformSynchronization: Server locked, try again later");
 					SetState (SyncState.Idle);
 					syncThread = null;
 					addin.PostSyncCleanup ();
@@ -892,7 +897,7 @@ namespace Tomboy.Sync
 		private string GetInnerContent (string fullContentElement)
 		{
 			const string noteContentRegex =
-				@"^<note-content(\s+version=""(?<contentVersion>[^""]*)"")?\s*((/>)|(>(?<innerContent>.*)</note-content>))$";
+				@"^<note-content([^>]+version=""(?<contentVersion>[^""]*)"")?[^>]*((/>)|(>(?<innerContent>.*)</note-content>))$";
 			Match m = Regex.Match (fullContentElement, noteContentRegex, RegexOptions.Singleline);
 			Group contentGroup = m.Groups ["innerContent"];
 			if (!contentGroup.Success)
